16.123. cdist-type__postfix(7) — cdist 6.9.8 documentation

# 16.123. cdist-type__postfix(7)

## 16.123.1. NAME

cdist-type__postfix - Install postfix

## 16.123.2. DESCRIPTION

This space intentionally left blank.

## 16.123.3. REQUIRED PARAMETERS

None.

## 16.123.4. OPTIONAL PARAMETERS

None.

## 16.123.5. EXAMPLES

    __postfix

## 16.123.6. AUTHORS

Steven Armstrong <steven-cdist--@--armstrong.cc>

## 16.123.7. COPYING

Copyright (C) 2012 Steven Armstrong. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.